@@ -1,8 +1,8 @@
-use strict;
+use v5.12.0;
 use warnings;
-package Data::Rx::CoreType::int;
+package Data::Rx::CoreType::int 0.200008;
 # ABSTRACT: the Rx //int type
-$Data::Rx::CoreType::int::VERSION = '0.200007';
+
 use parent 'Data::Rx::CoreType::num';
 
 sub subname   { 'int' }
@@ -37,15 +37,25 @@ Data::Rx::CoreType::int - the Rx //int type
 
 =head1 VERSION
 
-version 0.200007
+version 0.200008
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo SIGNES.
+This software is copyright (c) 2023 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
