@@ -1,8 +1,8 @@
-use strict;
+use v5.12.0;
 use warnings;
-package Data::Rx::Failure;
+package Data::Rx::Failure 0.200008;
 # ABSTRACT: structured failure report from an Rx checker
-$Data::Rx::Failure::VERSION = '0.200007';
+
 #pod =head1 SYNOPSIS
 #pod
 #pod This is part of a L<Data::Rx::FailureSet>, which is what is thrown when a
@@ -151,7 +151,7 @@ Data::Rx::Failure - structured failure report from an Rx checker
 
 =head1 VERSION
 
-version 0.200007
+version 0.200008
 
 =head1 SYNOPSIS
 
@@ -159,13 +159,23 @@ This is part of a L<Data::Rx::FailureSet>, which is what is thrown when a
 schema's C<assert_valid> method finds a problem with the input.  For more
 information on it, look at the documentation for L<Data::Rx>.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo SIGNES.
+This software is copyright (c) 2023 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
