@@ -1,8 +1,8 @@
-use strict;
+use v5.12.0;
 use warnings;
-package Data::Rx::Util;
+package Data::Rx::Util 0.200008;
 # ABSTRACT: helper routines for Data::Rx
-$Data::Rx::Util::VERSION = '0.200007';
+
 use Carp ();
 use List::Util ();
 use Number::Tolerant ();
@@ -40,12 +40,12 @@ sub _make_range_check {
     if exists $arg->{max};
   push @tolerances, Number::Tolerant->new(less_than => $arg->{'max-ex'})
     if exists $arg->{'max-ex'};
-  
+
   my $tol = do {
     no warnings 'once';
     List::Util::reduce { $a & $b } @tolerances;
   };
-  
+
   return sub { $_[0] == $tol };
 }
 
@@ -63,15 +63,25 @@ Data::Rx::Util - helper routines for Data::Rx
 
 =head1 VERSION
 
-version 0.200007
+version 0.200008
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo SIGNES.
+This software is copyright (c) 2023 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
